<?php

/**
 * This is the model class for table "per".
 *
 * The followings are the available columns in table 'per':
 * @property string $perid
 * @property string $fyear
 * @property string $perdesc
 * @property integer $peryear
 * @property integer $perno
 * @property string $perstart
 * @property string $perend
 * @property string $perstatus
 * @property boolean $active
 *
 * The followings are the available model relations:
 * @property Begbal[] $begbals
 * @property Bgt[] $bgts
 * @property Bpa[] $bpas
 * @property Casha[] $cashas
 * @property Cstr[] $cstrs
 * @property Cons[] $cons
 * @property Cret[] $crets
 * @property Deo[] $deos
 * @property Jnl[] $jnls
 * @property Mfg[] $mfgs
 * @property Lgr[] $lgrs
 * @property Prcv[] $prcvs
 * @property Po[] $pos
 * @property Preq[] $preqs
 * @property Rcv[] $rcvs
 * @property Purc[] $purcs
 * @property Sadj[] $sadjs
 * @property Sret[] $srets
 * @property Stocka[] $stockas
 * @property Pay[] $pays
 * @property So[] $sos
 * @property Cadj[] $cadjs
 * @property Fcn[] $fcns
 * @property Sale[] $sales
 * @property Deli[] $delis
 * @property Pret[] $prets
 * @property Fyear $fyear0
 * @property Sttr[] $sttrs
 */
class Per extends CActiveRecord {

    /**
     * Returns the static model of the specified AR class.
     * @param string $className active record class name.
     * @return Per the static model class
     */
    public static function model($className=__CLASS__) {
        return parent::model($className);
    }

    /**
     * @return string the associated database table name
     */
    public function tableName() {
        return 'per';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('perid', 'required'),
            array('peryear, perno', 'numerical', 'integerOnly' => true),
            array('perid', 'length', 'max' => 5),
            array('fyear', 'length', 'max' => 44),
            array('perdesc', 'length', 'max' => 50),
            array('perstatus', 'length', 'max' => 2),
            array('perstart, perend, active', 'safe'),
            // The following rule is used by search().
            // Please remove those attributes that should not be searched.
            array('perid, fyear, perdesc, peryear, perno, perstart, perend, perstatus, active', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'begbals' => array(self::HAS_MANY, 'Begbal', 'perid'),
            'bgts' => array(self::HAS_MANY, 'Bgt', 'perid'),
            'bpas' => array(self::HAS_MANY, 'Bpa', 'perid'),
            'cashas' => array(self::HAS_MANY, 'Casha', 'perid'),
            'cstrs' => array(self::HAS_MANY, 'Cstr', 'perid'),
            'cons' => array(self::HAS_MANY, 'Cons', 'perid'),
            'crets' => array(self::HAS_MANY, 'Cret', 'perid'),
            'deos' => array(self::HAS_MANY, 'Deo', 'perid'),
            'jnls' => array(self::HAS_MANY, 'Jnl', 'perid'),
            'mfgs' => array(self::HAS_MANY, 'Mfg', 'perid'),
            'lgrs' => array(self::HAS_MANY, 'Lgr', 'perid'),
            'prcvs' => array(self::HAS_MANY, 'Prcv', 'perid'),
            'pos' => array(self::HAS_MANY, 'Po', 'perid'),
            'preqs' => array(self::HAS_MANY, 'Preq', 'perid'),
            'rcvs' => array(self::HAS_MANY, 'Rcv', 'perid'),
            'purcs' => array(self::HAS_MANY, 'Purc', 'perid'),
            'sadjs' => array(self::HAS_MANY, 'Sadj', 'perid'),
            'srets' => array(self::HAS_MANY, 'Sret', 'perid'),
            'stockas' => array(self::HAS_MANY, 'Stocka', 'perid'),
            'pays' => array(self::HAS_MANY, 'Pay', 'perid'),
            'sos' => array(self::HAS_MANY, 'So', 'perid'),
            'cadjs' => array(self::HAS_MANY, 'Cadj', 'perid'),
            'fcns' => array(self::HAS_MANY, 'Fcn', 'perid'),
            'sales' => array(self::HAS_MANY, 'Sale', 'perid'),
            'delis' => array(self::HAS_MANY, 'Deli', 'perid'),
            'prets' => array(self::HAS_MANY, 'Pret', 'perid'),
            'fyear0' => array(self::BELONGS_TO, 'Fyear', 'fyear'),
            'sttrs' => array(self::HAS_MANY, 'Sttr', 'perid'),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'perid' => Yii::t('per', 'perid'),
            'fyear' => Yii::t('per', 'fyear'),
            'perdesc' => Yii::t('per', 'perdesc'),
            'peryear' => Yii::t('per', 'peryear'),
            'perno' => Yii::t('per', 'perno'),
            'perstart' => Yii::t('per', 'perstart'),
            'perend' => Yii::t('per', 'perend'),
            'perstatus' => Yii::t('per', 'perstatus'),
            'active' => Yii::t('per', 'active'),
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
     */
    public function search() {
        // Warning: Please modify the following code to remove attributes that
        // should not be searched.

        $criteria = new CDbCriteria;

        $criteria->compare('perid', $this->perid, true);
        $criteria->compare('fyear', $this->fyear, true);
        $criteria->compare('perdesc', $this->perdesc, true);
        $criteria->compare('peryear', $this->peryear);
        $criteria->compare('perno', $this->perno);
        $criteria->compare('perstart', $this->perstart, true);
        $criteria->compare('perend', $this->perend, true);
        $criteria->compare('perstatus', $this->perstatus, true);
        $criteria->compare('active', $this->active);

        return new CActiveDataProvider($this, array(
                    'criteria' => $criteria,
                ));
    }

    public function getPerActive() {
        $model = self::model()->findByAttributes(array('active' => true));
        if ($model != null) {
            return $model->perid;
        } else {
            return null;
        }
    }

}