<?php

/**
 * This is the model class for table "usr".
 *
 * The followings are the available columns in table 'usr':
 * @property string $usrid
 * @property string $empid
 * @property string $usrname
 * @property string $passwd
 * @property string $lastlogintime
 * @property string $lastloginfrom
 * @property boolean $disabled
 *
 * The followings are the available model relations:
 * @property Crc[] $crcs
 * @property Prc[] $prcs
 * @property Grp[] $grps
 * @property Emp $emp
 * @property Posses[] $posses
 */
class Usr extends CActiveRecord
{
	/**
	 * Returns the static model of the specified AR class.
	 * @param string $className active record class name.
	 * @return Usr the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'usr';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('usrid', 'required'),
			array('usrid', 'length', 'max'=>10),
			array('empid', 'length', 'max'=>15),
			array('usrname, passwd', 'length', 'max'=>50),
			array('lastloginfrom', 'length', 'max'=>16),
			array('lastlogintime, disabled', 'safe'),
			// The following rule is used by search().
			// Please remove those attributes that should not be searched.
			array('usrid, empid, usrname, passwd, lastlogintime, lastloginfrom, disabled', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'crcs' => array(self::HAS_MANY, 'Crc', 'usrid'),
			'prcs' => array(self::HAS_MANY, 'Prc', 'usrid'),
			'grps' => array(self::MANY_MANY, 'Grp', 'usrgrp(usrid, grpid)'),
			'emp' => array(self::BELONGS_TO, 'Emp', 'empid'),
			'posses' => array(self::HAS_MANY, 'Posses', 'usrid'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'usrid' => Yii::t('usr', 'usrid'),
			'empid' => Yii::t('usr', 'empid'),
			'usrname' => Yii::t('usr', 'usrname'),
			'passwd' => Yii::t('usr', 'passwd'),
			'lastlogintime' => Yii::t('usr', 'lastlogintime'),
			'lastloginfrom' => Yii::t('usr', 'lastloginfrom'),
			'disabled' => Yii::t('usr', 'disabled'),
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
	 */
	public function search()
	{
		// Warning: Please modify the following code to remove attributes that
		// should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('usrid',$this->usrid,true);
		$criteria->compare('empid',$this->empid,true);
		$criteria->compare('usrname',$this->usrname,true);
		$criteria->compare('passwd',$this->passwd,true);
		$criteria->compare('lastlogintime',$this->lastlogintime,true);
		$criteria->compare('lastloginfrom',$this->lastloginfrom,true);
		$criteria->compare('disabled',$this->disabled);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}
}